@@ -40,7 +40,10 @@ RcppExport SEXP loglik_AtEt_epsp_c(SEXP v_b_a, SEXP v_b_e, SEXP pheno_m, SEXP ph
 	arma::mat k_1d(2,2);
 	arma::mat k_2d(2,2);
 	arma::mat k_3d(2,2);
-	k_1d << 0.5 << 0 << arma::endr << 0 << 0.5 << arma::endr;
+	// k_1d << 0.5 << 0 << arma::endr << 0 << 0.5 << arma::endr;
+	k_1d.zeros();
+	k_1d(0,0) = 0.5;
+	k_1d(1,1) = 0.5;
 	arma::vec  v = arma::ones<arma::vec>(2);
 	arma::mat diag = arma::diagmat(v);
 	int penal_a = 2;
@@ -216,7 +219,10 @@ RcppExport SEXP loglik_AtEt_epsp_g_c(SEXP b_a, SEXP b_e, SEXP pheno_m, SEXP phen
 	arma::mat k_1d(2,2);
 	arma::mat k_2d(2,2);
 	arma::mat k_3d(2,2);
-	k_1d << 0.5 << 0 << arma::endr << 0 << 0.5 << arma::endr;
+	// k_1d << 0.5 << 0 << arma::endr << 0 << 0.5 << arma::endr;
+	k_1d.zeros();
+	k_1d(0,0) = 0.5;
+	k_1d(1,1) = 0.5;
 	arma::vec  v = arma::ones<arma::vec>(2);
 	arma::mat diag = arma::diagmat(v);
 	
@@ -304,7 +310,10 @@ RcppExport SEXP gr_AtEt_epsp_g_c(SEXP b_a, SEXP b_e, SEXP pheno_m, SEXP pheno_d,
 	arma::mat k_1d(2,2);
 	arma::mat k_2d(2,2);
 	arma::mat k_3d(2,2);
-	k_1d << 0.5 << 0 << arma::endr << 0 << 0.5 << arma::endr;
+	// k_1d << 0.5 << 0 << arma::endr << 0 << 0.5 << arma::endr;
+	k_1d.zeros();
+	k_1d(0,0) = 0.5;
+	k_1d(1,1) = 0.5;
 	arma::vec  v = arma::ones<arma::vec>(2);
 	arma::mat diag = arma::diagmat(v);
 	
@@ -414,7 +423,10 @@ RcppExport SEXP gr_AtEt_epsp_c(SEXP v_b_a, SEXP v_b_e, SEXP pheno_m, SEXP pheno_
 	arma::mat k_1d(2,2);
 	arma::mat k_2d(2,2);
 	arma::mat k_3d(2,2);
-	k_1d << 0.5 << 0 << arma::endr << 0 << 0.5 << arma::endr;
+	// k_1d << 0.5 << 0 << arma::endr << 0 << 0.5 << arma::endr;
+	k_1d.zeros();
+	k_1d(0,0) = 0.5;
+	k_1d(1,1) = 0.5;
 	arma::vec  v = arma::ones<arma::vec>(2);
 	arma::mat diag = arma::diagmat(v);
 	int penal_a = 2;
